/**************************************************************/
/*                                                            */
/*   File name :  libspeplot.h                                */
/*                                                            */
/*      Version:   2015-10-28                                 */
/*                                                            */
/*   Copyright (c) 2007-2015 T.Kondo/NICT All Right Reserved  */
/*                                                            */
/**************************************************************/
/*

  this library requires libvssp32

2015-10-28
  establish as an independent library
2014-10-29
  mindbm and maxdbm were added to the member of speana_param_t type variable
2007-11-13
  divide libspeplot.h into libspeplot.h and libspeplot.c
2007-11-04  
  improve appearance in case of GNUPLOT postscript
2007-11-02  
  support GNUPLOT
2006-01-31
  libspeplot.h includes functions used for spectrum plot.
*/
#ifndef _LIBSPEPLOT_
#define _LIBSPEPLOT_

#include "libk5.h"      // 2015-10-27
#include "g_head.h"    // header for graphics

#ifdef WIN32
int tempcounter;  // counter for tempfile manage
#endif

//#ifdef WIN32
//extern tempcounter;  // counter for tempfile manage
//#endif

typedef struct speana_param   // speana parameter type variable  (moved from libipvlbi_board.h)
{
    char fname[128]; // data file name
    char ftemp[128]; // temporary file name
    char g_device[30]; // current graphic device name 
    char g_display[30]; // graphic device name for display in case of GNUPLOT
    char g_ps_device[30]; // graphic device name for POSTSCRIPT
    char ps_fname[128]; // Postscript out file name
    char comment[60];
    char title[60];
    char lab1[128];
    char lab2[128];
    int flag_g_device_open;  // 2015-11-04
    int sfreq;
    int adbit;
    int numch;
    int nfft;
    int usampl;
    int amode;
    int pmode;
    int mode2;
    int mode;
    int time1st[3]; // hh,mm,ss
    int flag_halt;
    int sleep_msec;
    int nadata;      // # of samples per tspan 
    float *spows, *xdata, *ydata, *fdat, *adata, *tdat;
    double sekibun1;  // given unit integration period
    double sekibun;  // given integration period
    double tinteg;  // actual integration period
    //int soffset;  // start offset
    double soffset;  // start offset in floating second 2014-08-12
    double f1khz;  
    double f2khz;
    double mindbm;   // plot amplitude range
    double maxdbm;   //     "
    double tspan;  // plot time span in time series plot
    double toffset; // plot time offset from start
    double ymaxdb,ymindb;
    FILE *gp;   // for GNUPLOT 

} speana_param_t;

void tmpnameget(char *tmpdir, char *fpath);  // original is in libcor.c
void plotspe(speana_param_t *st, float ymaxdb, float ymindb);
void plotspe2(speana_param_t *st);

void plotspe_a(speana_param_t *st, float ymaxdb, float ymindb);
void plotspe_a2(speana_param_t *st,float *pmaxdat, 
               float *fdatmax, int nmax);
void plotautocor(speana_param_t *st);

void gnline(FILE *gp,  int ndata,float *xdata, float *ydata);
void gnline2(FILE *gp,  int ndata,float *xdata, float *ydata, char *ftemp);

void plottime(speana_param_t *st);
void plottime_a(speana_param_t *st, int mch);

void spe_sleep(int msec);  // suspend msec 

void plotspe_new(speana_param_t *st);
void plotspe_a_new(speana_param_t *st, float ymaxdb, float ymindb, int mch);


#endif
